@@ -4,4 +4,4 @@ if [ ! -d "m4" ]; then
 	mkdir m4
 fi
 
-autoreconf -i
+autoreconf -fvi
