@@ -90,42 +90,55 @@ bool ExtendedHypertree::isRoot() const
 }
 
 ExtendedHypertree *ExtendedHypertree::normalize(NormalizationType normalization)
+{
+	if(normalization == StrongNormalization) return this->normalize(normalization, true, false);
+	else return this->normalize(normalization, false, false);
+}
+
+ExtendedHypertree *ExtendedHypertree::normalize(NormalizationType normalization, bool emptyLeafs, bool emptyRoot)
 {
 	ExtendedHypertree *current = new ExtendedHypertree(this->vertices);
 
 	if(this->MyChildren.size() == 0)
 	{
 		ExtendedHypertree *empty = NULL;
+		if(emptyLeafs) empty = new ExtendedHypertree(VertexSet());
 
 		switch(normalization)
 		{
 		case NoNormalization:
 		case DefaultNormalization:
-			current->type = Leaf;
+		case StrongNormalization:
 			break;
 		case SemiNormalization:
-			current->type = Leaf;
+		case WeakNormalization:
 			current->introduced = current->vertices;
 			break;
-		case StrongNormalization:
-			empty = new ExtendedHypertree(VertexSet());
-			empty->type = Leaf;
-			current->insChild(empty);
-			empty->adapt();
-			break;
 		default:
 			CHECK0(0, "undefined normalization type"); return NULL;
 		}
+
+		if(!emptyLeafs) current->type = Leaf;
+		else
+		{
+			empty->type = Leaf;
+			current->type = Permutation;
+			current->insChild(empty);
+
+			if(normalization == DefaultNormalization || normalization == StrongNormalization)
+				empty->adapt();
+		}
 	}
 	else if(this->MyChildren.size() == 1)
 	{
-		ExtendedHypertree *child = ((ExtendedHypertree *)*this->MyChildren.begin())->normalize(normalization);
+		ExtendedHypertree *child = ((ExtendedHypertree *)*this->MyChildren.begin())->normalize(normalization, emptyLeafs, emptyRoot);
 		current->insChild(child);
 
 		switch(normalization)
 		{
 		case NoNormalization:
 		case SemiNormalization:
+		case WeakNormalization:
 			current->type = Permutation;
 			set_difference(current->vertices.begin(), current->vertices.end(),
 					child->vertices.begin(), child->vertices.end(),
@@ -147,16 +160,36 @@ ExtendedHypertree *ExtendedHypertree::normalize(NormalizationType normalization)
 		if(normalization == NoNormalization)
 		{
 			for(list<Hypertree *>::const_iterator i = this->MyChildren.begin(); i != this->MyChildren.end(); ++i)
-				current->insChild(((ExtendedHypertree *)*i)->normalize(normalization));
+				current->insChild(((ExtendedHypertree *)*i)->normalize(normalization, emptyLeafs, emptyRoot));
 		}
-		else
+		else if(normalization == WeakNormalization)
+		{
+			current->type = Branch;
+			
+			for(list<Hypertree *>::const_iterator i = this->MyChildren.begin(); i != this->MyChildren.end(); ++i)
+			{
+				ExtendedHypertree *joinchild = new ExtendedHypertree(current->vertices);
+				ExtendedHypertree *child = ((ExtendedHypertree *)*i)->normalize(normalization, emptyLeafs, emptyRoot);
+
+				set_difference(joinchild->vertices.begin(), joinchild->vertices.end(),
+						child->vertices.begin(), child->vertices.end(),
+						inserter(joinchild->introduced, joinchild->introduced.begin()));
+				set_difference(child->vertices.begin(), child->vertices.end(),
+						joinchild->vertices.begin(), joinchild->vertices.end(),
+						inserter(joinchild->removed, joinchild->removed.begin()));
+
+				joinchild->insChild(child);
+				current->insChild(joinchild);
+			}
+		}
+		else // semi-normalization or stronger
 		{
 			vector<ExtendedHypertree *> childlist;
 			vector<ExtendedHypertree *> newchildren;
 
 			for(list<Hypertree *>::const_iterator i = this->MyChildren.begin(); i != this->MyChildren.end(); ++i)
 			{
-				newchildren.push_back(((ExtendedHypertree *)*i)->normalize(normalization));
+				newchildren.push_back(((ExtendedHypertree *)*i)->normalize(normalization, emptyLeafs, emptyRoot));
 			}
 
 			while(newchildren.size() > 1)
@@ -203,7 +236,17 @@ ExtendedHypertree *ExtendedHypertree::normalize(NormalizationType normalization)
 		}
 	}
 
-	return current;
+	if(emptyRoot && this->MyParent == NULL) // add empty root node
+	{
+		ExtendedHypertree *root = new ExtendedHypertree(VertexSet());
+		root->insChild(current);
+
+		if(normalization == DefaultNormalization || normalization == StrongNormalization)
+			current->adapt();
+
+		return root;
+	}
+	else return current;
 }
 
 ExtendedHypertree *ExtendedHypertree::createNormalizedJoinNode(ExtendedHypertree *left, ExtendedHypertree *right, const VertexSet &top, NormalizationType normalization)
